@@ -10,9 +10,9 @@
 
 extern "C" {
 
-static const char* FILE_NAME = "R/OP/Matrix/floatComplex.cpp";
+static const char* FILE_NAME = "R/OP/Matrix/FloatComplex.cpp";
 
-int32_t SPVM__R__OP__Matrix__floatComplex___mul(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__R__OP__Matrix__FloatComplex___mul(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t e = 0;
   
@@ -59,7 +59,7 @@ int32_t SPVM__R__OP__Matrix__floatComplex___mul(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 }
 
-int32_t SPVM__R__OP__Matrix__floatComplex___t(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__R__OP__Matrix__FloatComplex___t(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t e = 0;
   
@@ -99,7 +99,7 @@ int32_t SPVM__R__OP__Matrix__floatComplex___t(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 }
 
-int32_t SPVM__R__OP__Matrix__floatComplex___det(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__R__OP__Matrix__FloatComplex___det(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t e = 0;
   
@@ -137,7 +137,7 @@ int32_t SPVM__R__OP__Matrix__floatComplex___det(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 }
 
-int32_t SPVM__R__OP__Matrix__floatComplex___solve(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__R__OP__Matrix__FloatComplex___solve(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t e = 0;
   
@@ -175,56 +175,65 @@ int32_t SPVM__R__OP__Matrix__floatComplex___solve(SPVM_ENV* env, SPVM_VALUE* sta
   return 0;
 }
 
-int32_t SPVM__R__OP__Matrix__floatComplex___eigen(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__R__OP__Matrix__FloatComplex___eigen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t e = 0;
   
-  void* obj_ret_data_ref = stack[0].oval;
+  void* obj_eigen_vectors_data_ref = stack[0].oval;
   
-  int32_t* ret_nrow_ref = stack[1].iref;
+  int32_t* eigen_vectors_nrow_ref = stack[1].iref;
   
-  int32_t* ret_ncol_ref = stack[2].iref;
+  int32_t* eigen_vectors_ncol_ref = stack[2].iref;
   
-  void* obj_x_data = stack[3].oval;
+  void* obj_eigen_values_data_ref = stack[3].oval;
+  
+  int32_t* eigen_values_nrow_ref = stack[4].iref;
+  
+  int32_t* eigen_values_ncol_ref = stack[5].iref;
+  
+  void* obj_x_data = stack[6].oval;
   std::complex<float>* x_data = (std::complex<float>*)env->get_elems_float(env, stack, obj_x_data);
   
-  int32_t x_nrow = stack[4].ival;
+  int32_t x_nrow = stack[7].ival;
   
-  int32_t x_ncol = stack[5].ival;
-  
-  void* obj_eigen_values_data_ref = stack[6].oval;
+  int32_t x_ncol = stack[8].ival;
   
   Eigen::Matrix<std::complex<float>, Eigen::Dynamic, Eigen::Dynamic> x_matrix = Eigen::Map<Eigen::Matrix<std::complex<float>, Eigen::Dynamic, Eigen::Dynamic>>(x_data, x_nrow, x_ncol);
   
-  Eigen::SelfAdjointEigenSolver<Eigen::Matrix<std::complex<float>, Eigen::Dynamic, Eigen::Dynamic>> eigen_solver(x_matrix);
-  
-  Eigen::Matrix<std::complex<float>, Eigen::Dynamic, 1> eigen_values = eigen_solver.eigenvalues();
+  Eigen::ComplexEigenSolver<Eigen::Matrix<std::complex<float>, Eigen::Dynamic, Eigen::Dynamic>> eigen_solver(x_matrix);
   
   Eigen::Matrix<std::complex<float>, Eigen::Dynamic, Eigen::Dynamic> eigen_vectors = eigen_solver.eigenvectors();
   
-  int32_t ret_length = eigen_vectors.rows() * eigen_vectors.cols();
-  void* obj_ret_data = env->new_mulnum_array_by_name(env, stack, "Complex_2f", ret_length, &e, __func__, FILE_NAME, __LINE__);
+  Eigen::Matrix<std::complex<float>, Eigen::Dynamic, 1> eigen_values = eigen_solver.eigenvalues();
+  
+  int32_t eigen_vectors_length = eigen_vectors.rows() * eigen_vectors.cols();
+  void* obj_eigen_vectors_data = env->new_mulnum_array_by_name(env, stack, "Complex_2f", eigen_vectors_length, &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
-  std::complex<float>* ret_data = (std::complex<float>*)env->get_elems_float(env, stack, obj_ret_data);
+  std::complex<float>* eigen_vectors_data = (std::complex<float>*)env->get_elems_float(env, stack, obj_eigen_vectors_data);
   
-  memcpy(ret_data, eigen_vectors.data(), sizeof(std::complex<float>) * ret_length);
+  memcpy(eigen_vectors_data, eigen_vectors.data(), sizeof(std::complex<float>) * eigen_vectors_length);
   
-  env->set_elem_object(env, stack, obj_ret_data_ref, 0, obj_ret_data);
+  env->set_elem_object(env, stack, obj_eigen_vectors_data_ref, 0, obj_eigen_vectors_data);
   
-  *ret_nrow_ref = eigen_vectors.rows();
+  *eigen_vectors_nrow_ref = eigen_vectors.rows();
   
-  *ret_ncol_ref = eigen_vectors.cols();
+  *eigen_vectors_ncol_ref = eigen_vectors.cols();
   
-  void* obj_eigen_values_data = env->new_mulnum_array_by_name(env, stack, "Complex_2f", eigen_values.size(), &e, __func__, FILE_NAME, __LINE__);
+  int32_t eigen_values_length = eigen_values.rows() * eigen_values.cols();
+  void* obj_eigen_values_data = env->new_mulnum_array_by_name(env, stack, "Complex_2f", eigen_values_length, &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   std::complex<float>* eigen_values_data = (std::complex<float>*)env->get_elems_float(env, stack, obj_eigen_values_data);
   
-  memcpy(eigen_values_data, eigen_values.data(), sizeof(std::complex<float>) * eigen_values.size());
+  memcpy(eigen_values_data, eigen_values.data(), sizeof(std::complex<float>) * eigen_values_length);
   
   env->set_elem_object(env, stack, obj_eigen_values_data_ref, 0, obj_eigen_values_data);
   
+  *eigen_values_nrow_ref = eigen_values.rows();
+  
+  *eigen_values_ncol_ref = eigen_values.cols();
+  
   return 0;
 }
 
